@@ -7,12 +7,12 @@ class Manager:
     def height_tree(self, obj):
         tobj = type(obj)
         if tobj not in self.deals:
-            raise Exception("undealable type"+str(obj))
+            raise Exception(f"undealable type {tobj}=="+str(obj))
         for fc in self.deals[tobj]:
             rst = fc.height_tree(self, obj)
             if rst is not None:
                 return rst
-        raise Exception("undealable obj in type"+str(obj))
+        raise Exception(f"undealable obj in type: {type(obj)}=="+str(obj))
     def add(self, types, fc):
         if type(types) not in (list, tuple):
             types = [types]
